@@ -1,9 +1,16 @@
-from typing import Union, Dict, Any
-from obschart.api.context import Context
+from typing import TYPE_CHECKING, Any, Dict
+
+if TYPE_CHECKING:
+    from .context import Context
+
+NodeData = Dict[str, Any]
 
 
 class Node(object):
-    def __init__(self, data: Dict[str, Any], context: Union[Context, None] = None):
+    _data: NodeData
+    _context: "Context"
+
+    def __init__(self, data: NodeData, context: "Context"):
         super().__init__()
 
         self._data = data
@@ -16,7 +23,9 @@ class Node(object):
         return self._context.client._execute(query, variables)
 
     def __repr__(self):
-        return f"{self.__class__.__name__} (ID: {self.id}) {self._data}"
+        clean_data = dict(self._data)
+        clean_data.pop("id")
+        return f"{self.__class__.__name__} (ID: {self.id}) {clean_data}"
 
     @property
     def id(self):
