@@ -1,3 +1,4 @@
+from .application import Application
 from .chat_channel import ChatChannel, chatChannelFragment
 from .client_profile_invitation import ClientProfileInvitation, clientProfileInvitationFragment
 from .image import Image, imageFragment
@@ -13,6 +14,7 @@ from .session import Session
 from .tag import Tag, tagFragment
 
 __all__ = [
+    "Application",
     "ChatChannel",
     "chatChannelFragment",
     "ClientProfileInvitation",
