@@ -11,7 +11,7 @@ fragment Image on Image {
 
 
 class Image(Node):
-    def __init__(self, data, context=None):
+    def __init__(self, data, context):
         super().__init__(data, context=context)
 
     @property
