@@ -56,7 +56,7 @@ class ObschartApiTransport(GqlClientTransport):
         else:
             response = await self._client.post(self._url, json=payload, timeout=timeout or UNSET)
 
-        # response.raise_for_status()
+        response.raise_for_status()
 
         result = response.json()
         assert isinstance(result, dict) and (
