@@ -43,27 +43,27 @@ class ObschartClient(ObschartApiClient):
         self.set_authentication_token(authentication_token)
         return session
 
+    async def run(self, on_response_callback: OnResponseCallback) -> Any:
+        while True:
+            responses = await self.poll_program_track_action_responses(
+                {"applicationId": {"eq": "me"}}
+            )
+
+            for response in responses:
+
+                async def task():
+                    try:
+                        log.debug("Handling response...")
+                        await on_response_callback(response)
+                        log.debug("Response handled")
+                    except:
+                        log.exception("Could not handle response: %s", response)
+
+                asyncio.ensure_future(task())
+
     def on_response(self, on_response_callback: OnResponseCallback):
-        async def main() -> Any:
-            while True:
-                responses = await self.poll_program_track_action_responses(
-                    {"applicationId": {"eq": "me"}}
-                )
-
-                for response in responses:
-
-                    async def task():
-                        try:
-                            log.debug("Handling response...")
-                            await on_response_callback(response)
-                            log.debug("Response handled")
-                        except:
-                            log.exception("Could not handle response: %s", response)
-
-                    asyncio.ensure_future(task())
-
         loop = asyncio.get_event_loop()
-        loop.run_until_complete(main())
+        loop.run_until_complete(self.run(on_response_callback))
         # https://stackoverflow.com/a/37345564/11225752
         # loop.run_until_complete(asyncio.Task.all_tasks())
 
